<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klik ikon talam
atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Jangan putar skrin anda ketika merakam</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Rakaman</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Tangkap Skrin</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Gagal simpan. Sila simpan ia dalam direktori rumah anda.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Tangkap layar selesai</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>pilih-kawasan</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Disimpan ke %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abai</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Papan keratan</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Menyimpan fail rakaman skrin, tunggu sebentar...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Setelah kesan tetingkap dilumpuhkan ketika proses, rakaman telah dihentikan</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Tangkap tatal</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Cemat Tangkap Layar</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Buka Folder</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Skrinshot tamat dan salinan ke papan klip</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Buat Asal</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Cemat Tangkap Layar</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rakam</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Merakam</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Rakaman selesai</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Disimpan ke %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rakam</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Buka Folder</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Tangkap Skrin akan bermula dalam tempoh %1 saat</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Dapatkan bantuan.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Gagal mengambil tangkap layar berterusan.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Sampai bahagian terbawah kawasan tatal</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Sampai panjang maksimum</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Laras kawasan tangkapan</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Tatal roda tetikus anda atau klik untuk menatal tangkap layar</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Perlahankan kelajuan tatal</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Kawasan tidak sah, klik ke </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Masukkan teks di sini</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Mula/Tangkap Layar</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Keluar/Simpan</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Pelarasan Saiz</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Mula pantas</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Tangkap layar tetingkap</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Tangkap layar lengah</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tangkap layar penuh</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Petak</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Garisan</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pensel</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Buat Asal</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Tingkatkan tinggi ke atas</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Tingkatkan tinggi ke bawah</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Tingkatkan lebar ke kiri</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Tingkatkan lebar ke kanan</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Kurangkan tinggi ke atas</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Kurangkan tinggi ke bawah</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Kurangkan lebar ke kiri</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Kurangkan lebar ke kanan</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Bunyi</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Ketukan kekunci</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera sesawang</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Mula merakam</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Mula/Rakaman</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Tetikus</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alatan</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ekstrak teks</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Tangkap tatal</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Cemat tangkap layar</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Mula OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Mula tangkap tatal</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Anak Panah</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Rakam</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Segi Empat
Tekan dan tahan kekunci Shift untuk membentuk sebuah petak</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elips
Tekan dan tahan kekunci Shift untuk membentuk sebuah bulatan</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Berus
Tekan dan tahan kekunci Shift untuk membentuk satu garisan lurus</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Laras kekuatan kabur (Tatal untuk melarasnya)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Laras saiz berus (Tatal untuk melarasnya)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Laras saiz teks (Tatal untuk melarasnya)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Tunjuk ketukan kekunci (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Sembunyi Ketukan Kekunci (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Tunjuk Ketukan Kekunci (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Hidupkan kamera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Matikan kamera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Tangkap Layar</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Tetapan (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Bunyi</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio sistem</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Tunjuk penuding</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Tunjuk klik</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Simpan ke</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Atas Meja</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Garisan (L)
Tekan dan tahan kekunci Shift untuk melukis garisan menegak atau mengufuk</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Anak panah (X)
Tekan dan tahan kekunci Shift untuk melukis anak panah menegak atau mengufuk</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Pensel (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Kabur (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Teks (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Tangkapbertatal (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Ekstrak teks (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Cemat tangkap layar (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Buat asal (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Rakam</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Tetapkan laluan ketika simpan</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Ubah laluan ketika simpan</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Kesan Sempadan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Tiada</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Bayang</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Sempadan</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Peranti</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Ekstrak Teks</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Alat Geometri (R)
Tahan Shift untuk melukis segi empat sama atau bulatan.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Simpan ke lokal</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Simpan ke Desktop</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Simpan ke Gambar</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Simpan ke %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Lokasi Tertentu</translation>
    </message>
    <message>
        <source>Custom Location</source>
        <translation>Lokasi Pilihan</translation>
    </message>
    <message>
        <source>Each inquiry</source>
        <translation>Setiap pertanyaan</translation>
    </message>
    <message>
        <source>Update location on save</source>
        <translation>Kemaskini lokasi semasa simpan</translation>
    </message>
    <message>
        <source>Save to desktop</source>
        <translation>Simpan ke Desktop</translation>
    </message>
    <message>
        <source>Save to pictures</source>
        <translation>Simpan ke Gambar</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Tutup (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Salin ke papan klip (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Laras kawasan rakaman dalam lingkungan %1*%2 untuk mendapatkan kesan video lebih baik</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Rakaman skrin masih tidak disokong buat masa ini</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
</TS>
